#
# spec file for package perl-Capture-Tiny
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Capture-Tiny
Version:        0.23
Release:        5.3
%define cpan_name Capture-Tiny
Summary:        Capture STDOUT and STDERR from Perl, XS or external programs
License:        Apache-2.0
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Capture-Tiny/
Source:         http://www.cpan.org/authors/id/D/DA/DAGOLDEN/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
Patch0:         Capture-Tiny-0.2.3-CVE-2014-1875.patch
#BuildRequires: perl(Capture::Tiny)
#BuildRequires: perl(Cases)
#BuildRequires: perl(Inline)
#BuildRequires: perl(Pod::Wordlist)
#BuildRequires: perl(Test::Differences)
#BuildRequires: perl(Test::Spelling) >= 0.12
#BuildRequires: perl(TieEvil)
#BuildRequires: perl(TieLC)
#BuildRequires: perl(Utils)
%{perl_requires}

%description
Capture::Tiny provides a simple, portable way to capture almost anything
sent to STDOUT or STDERR, regardless of whether it comes from Perl, from XS
code or from an external program. Optionally, output can be teed so that it
is captured while being passed through to the original filehandles. Yes, it
even works on Windows (usually). Stop guessing which of a dozen capturing
modules to use in any particular situation and just use this one.

%prep
%setup -q -n %{cpan_name}-%{version}
%patch0 -p0

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING cpanfile examples LICENSE perlcritic.rc README Todo

%changelog
* Fri Feb 13 2015 vpereira@suse.com
-  CVE-2014-1875: Closed security hole in use of semaphore flag in /tmp;
  now opens semaphore the using O_CREAT|O_EXCL
* Tue Nov 26 2013 coolo@suse.com
- updated to 0.23
  Fixed:
  - minimum Perl prereq is back to 5.6 (but $diety help you if
    you're still stuck on 5.6)
  Documented:
  - Added warning about using @_ in a capture block
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.22
  Documented:
  - Issue tracker is now github
  Changed:
  - Skips tee and leak tests for closed STDIN on Perl prior to
    5.12 when PERL_UNICODE=D.  Documented lack of support as
    a known issue.
  - Isolated tee subprocesses from effects of PERL_UNICODE as a
    precaution (though this did not fix the above issue).
  - Improved layer detection for handles proxied due to being closed
    or tied.
  Fixed:
  - Nested merged captures that include an external program call no longer
    leak STDERR to the outer scope [rt.cpan.org #79376]
  - Work around rt.perl.org #114404 by forcing PerlIO layers back on
    original handles [rt.cpan.org #78819]
* Wed May 23 2012 coolo@suse.com
- updated to 0.18
  Added
  - When capture or tee are called in void context, Capture::Tiny
    skips reading back from the capture handles if it can do so safely
  Fixed:
  - Tied STDIN is always localized before redirections to avoid tees
    hanging on MSWin32
  - Copying and reopening STDIN is necessary to avoid tees hanging on MSWin32.
  Fixed:
  - Avoids reopening STDIN while setting up a capture, which avoids
    some problems with pathological tied filehandle implementations
    such as in FCGI
  Tested:
  - Re-enabled tied STDIN testing for MSWin32 to see if changes above
    avoid crashes seen historically
* Mon Feb 27 2012 coolo@suse.com
- updated to 0.17
  Fixed:
  - Added a workaround for failing t/08-stdin-closed.t under blead
    perl / 5.15.8 [RT#111070]
  Documented:
  - Clarified some limitations; added a link to CPAN Testers Matrix;
    removed redundant BUGS section; standardized terminology
  Tested:
  - Added a test using Inline::C to print to stdout and stderr in response
    to RT#71701
* Tue Feb 21 2012 coolo@suse.com
- updated to 0.16
  - Noted problems and workaround for FCGI's pathological tied STDIN
    [RT#74681; thank you Karl Gaissmaier for testing the
    workaround]
* Sat Dec 24 2011 pascal.bleser@opensuse.org
- update to 0.15:
  * repeated captures from a custom filehandle would return undef instead of
    the empty string (and would warn). This has been fixed. RT#73374
  * commented out debugging code for slightly less runtime overhead
- changes from 0.14:
  * added: capturing with custom filehandles will return only newly appended
    output instead of everything already in the file RT#73374
* Wed Dec 21 2011 pascal.bleser@opensuse.org
- update to 0.13: no user-visible changes
- changes from 0.12:
  - add new functions capture_stdout, capture_stderr, tee_stdout, tee_stderr; RT#60515
  - capture functions also returns the return values from the executed coderef; RT#61794
  - capture functions take optional custom filehandles for capturing via named
    files instead of anonymous ones
  - tied filehandles based on Tie::StdHandle can now use the ":utf8" layer;
    removed remaining TODO tests; adds Scalar::Util as a dependency
  - when Time::HiRes::usleep is available, tee operations will
    sleep during the busy-loop waiting for tee processes to be ready
    RT#67858
* Fri Aug 26 2011 chris@computersalat.de
- fix build for SLE_10
  * %%{__perl} -p -i -e 's|6.31|6.30|' Makefile.PL
* Thu Jul 21 2011 coolo@novell.com
- updated to 0.11
  Fixed:
  - Tests will not use Test::Differences version 0.60 or greater
  - Setting PERL_CAPTURE_TINY_TIMEOUT to 0 will disable timeouts
  - Added support for $ENV{PERL_CAPTURE_TINY_TIMEOUT} to control
    the timeout period under 'tee'; tests set not to timeout to
    avoid false FAIL reports on overloaded virtual machine smokers
  Fixed:
  - $@ set within a captured block is no longer lost when the capture
    is completed; likewise, the initial value of $@ is not lost
    during capture (when no subsequent error occurs) (RT #65139)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Jun 21 2010 pascal.bleser@opensuse.org
- update to 0.08
* Tue Jan 26 2010 pascal.bleser@opensuse.org
- update to 0.07
* Thu Oct 29 2009 pascal.bleser@opensuse.org
- new package
